/**
 * Mark an object as mutable
 */
export declare type MutableMark = {
    /**
     * The mutable marker to mark an object as mutable. When assign readonly object to a mutable type, compile will fail to build
     * due to this member does not exist from source type.
     */
    readonly dummy1?: never[];
    /**
     * The mutable marker to mark an object as mutable. When assign readonly object to a mutable type, compile will fail to build
     * due to this member does not exist from source type.
     */
    readonly dummy2?: never[];
};
/**
 * Mark an object as single level mutable (child models are still readonly)
 */
export declare type ShallowMutableMark = {
    /**
     * The mutable marker to mark an object as mutable. When assign readonly object to a mutable type, compile will fail to build
     * due to this member does not exist from source type.
     */
    readonly dummy1?: never[];
    /**
     * The mutable marker to mark an object as mutable. When assign readonly object to a mutable type, compile will fail to build
     * due to this member does not exist from source type.
     * This is used for preventing assigning ShallowMutableMark to MutableMark
     */
    readonly dummy2?: ReadonlyArray<never>;
};
/**
 * Mark an object as readonly
 */
export declare type ReadonlyMark = {
    /**
     * The mutable marker to mark an object as mutable. When assign readonly object to a mutable type, compile will fail to build
     * due to this member does not exist from source type.
     * This is used for preventing assigning ReadonlyMark to ShallowMutableMark or MutableMark
     */
    readonly dummy1?: ReadonlyArray<never>;
    /**
     * The mutable marker to mark an object as mutable. When assign readonly object to a mutable type, compile will fail to build
     * due to this member does not exist from source type.
     */
    readonly dummy2?: ReadonlyArray<never>;
};
