/**
 * Define entity lifecycle related operations
 */
export declare type EntityLifecycleOperation = 
/**
 * Notify plugins that there is a new plugin was added into editor.
 * Plugin can handle this event to entity hydration.
 * This event will be only fired once for each entity DOM node.
 * After undo, or copy/paste, since new DOM nodes were added, this event will be fired
 * for those entities represented by newly added nodes.
 */
'newEntity'
/**
 * Notify plugins that editor is generating HTML content for save.
 * Plugin should use this event to remove any temporary content, and only leave DOM nodes that
 * should be saved as HTML string.
 * This event will provide a cloned DOM tree for each entity, do NOT compare the DOM nodes with cached nodes
 * because it will always return false.
 */
 | 'replaceTemporaryContent'
/**
 * This event is triggered when an undo snapshot is taken while a custom logical root is used
 * Plugins can handle this event to include entity state to include in the snapshot
 */
 | 'snapshotEntityState'
/**
 * Notify plugins that a new entity state need to be updated to an entity.
 * This is normally happened when user undo/redo the content with an entity snapshot added by a plugin that handles entity
 */
 | 'updateEntityState'
/**
 * Notify plugins that user is clicking target to an entity
 */
 | 'click';
/**
 * Define entity removal related operations
 */
export declare type EntityRemovalOperation = 
/**
 * Notify plugins that user is removing an entity from its start position using DELETE key
 */
'removeFromStart'
/**
 * Notify plugins that user is remove an entity from its end position using BACKSPACE key
 */
 | 'removeFromEnd'
/**
 * Notify plugins that an entity is being overwritten.
 * This can be caused by key in, cut, paste, delete, backspace ... on a selection
 * which contains some entities.
 */
 | 'overwrite';
/**
 * DEfine entity format related operations
 */
export declare type EntityFormatOperation = 
/**
 * Tell plugins we are doing format change and an entity is inside the selection.
 * Plugin can handle this event and put root level node (must be under the entity wrapper) into
 * event.formattableRoots so editor will create content models for each root and do format to their contents
 */
'beforeFormat';
/**
 * Define possible operations to an entity
 */
export declare type EntityOperation = EntityLifecycleOperation | EntityRemovalOperation | EntityFormatOperation;
